/* stdio.h: Standard input/output. */

#ifndef _STDIO_H
#define _STDIO_H

#include <stdarg.h>
#include <sys/types.h>

typedef struct
{
    int __unused;
} FILE;

#define SEEK_SET 0

extern FILE* stderr;
#define stderr stderr

#ifdef __cplusplus
extern "C"
{
#endif

    int fflush(FILE*);

    FILE* fopen(const char*, const char*);
    int fclose(FILE*);

    size_t fread(void*, size_t, size_t, FILE*);
    size_t fwrite(const void*, size_t, size_t, FILE*);

    int fseek(FILE*, long, int);
    long ftell(FILE*);

    void setbuf(FILE*, char*);

    int fprintf(FILE*, const char*, ...);
    int vfprintf(FILE*, const char*, va_list);

    /* Write formatted output into a buffer. */
    int sprintf(char* buf, const char* format, ...);

    /* Write up to max bytes of formatted output into a buffer. */
    int snprintf(char* buf, size_t max, const char* format, ...);

    /* Write formatted output into a buffer. */
    int vsprintf(char*, const char*, va_list);

    /* Write up to max bytes of formatted output into a buffer. */
    int vsnprintf(char*, size_t, const char*, va_list);

    /* Write formatted output to standard output. */
    int printf(const char*, ...);

    /* Write a string followed by a newline to standard output. */
    int puts(const char* s);

    /* Output a message to the console. */
    int console_write(const char* msg, size_t size);

#ifdef __cplusplus
}
#endif

#endif
